Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(987)

Unified Diff: third_party/WebKit/Source/modules/mediastream/MediaErrorState.h

Issue 1661493002: Add promise-based addIceCandidate, setLocalDescription and setRemoteDescription to RTCPeerConnection (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: philipj's comments on tests Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/mediastream/MediaErrorState.h
diff --git a/third_party/WebKit/Source/modules/mediastream/MediaErrorState.h b/third_party/WebKit/Source/modules/mediastream/MediaErrorState.h
index cd07d670e17016eddc177b57addd9dce4dea0de1..eaf782fbc0e1224a390873e6f2cae2cc882619e6 100644
--- a/third_party/WebKit/Source/modules/mediastream/MediaErrorState.h
+++ b/third_party/WebKit/Source/modules/mediastream/MediaErrorState.h
@@ -39,7 +39,7 @@ class NavigatorUserMediaError;
// A class that is able to be used like ExceptionState for carrying
// information about an error up the stack, but it is up to the higher
// level code whether it produces a DOMerror or a NavigatorUserMediaError.
class MediaErrorState {
public:
MediaErrorState();
@@ -51,12 +51,13 @@ public:
bool hadException();
bool canGenerateException();
void raiseException(ExceptionState&);
+ String getErrorMessage();
NavigatorUserMediaError* createError();
private:
enum ErrorType {
NoError,
TypeError,
- DOMError,
+ DOMException,
ConstraintError
};
ErrorType m_errorType;
@@ -39,7 +39,7 @@ class NavigatorUserMediaError;
// A class that is able to be used like ExceptionState for carrying
// information about an error up the stack, but it is up to the higher
-// level code whether it produces a DOMerror or a NavigatorUserMediaError.
+// level code whether it produces a DOMException or a NavigatorUserMediaError.
class MediaErrorState {
public:

Powered by Google App Engine
This is Rietveld 408576698